import fetch from 'cross-fetch';
import 'url-search-params-polyfill';
/**
 * Default transport implementation.
 */
export class HttpTransport {
    constructor({ authorization, apiUrl, method, headers = {}, credentials, fetchTimeout, signal }) {
        this.authorization = authorization;
        this.apiUrl = apiUrl;
        this.method = method;
        this.headers = headers;
        this.credentials = credentials;
        this.fetchTimeout = fetchTimeout;
        this.signal = signal;
    }
    request(method, { baseRequestId, signal, ...params }) {
        let spanCounter = 1;
        const searchParams = new URLSearchParams(params && Object.keys(params)
            .map(k => ({ [k]: typeof params[k] === 'object' ? JSON.stringify(params[k]) : params[k] }))
            .reduce((a, b) => ({ ...a, ...b }), {}));
        let url = `${this.apiUrl}/${method}${searchParams.toString().length ? `?${searchParams}` : ''}`;
        const requestMethod = this.method || (url.length < 2000 ? 'GET' : 'POST');
        if (requestMethod === 'POST') {
            url = `${this.apiUrl}/${method}`;
            this.headers['Content-Type'] = 'application/json';
        }
        // Currently, all methods make GET requests. If a method makes a request with a body payload,
        // remember to add {'Content-Type': 'application/json'} to the header.
        const runRequest = () => fetch(url, {
            method: requestMethod,
            headers: {
                Authorization: this.authorization,
                'x-request-id': baseRequestId && `${baseRequestId}-span-${spanCounter++}`,
                ...this.headers
            },
            credentials: this.credentials,
            body: requestMethod === 'POST' ? JSON.stringify(params) : null,
            signal: signal || this.signal || (this.fetchTimeout ? AbortSignal.timeout(this.fetchTimeout) : undefined),
        });
        return {
            /* eslint no-unsafe-finally: off */
            async subscribe(callback) {
                try {
                    const result = await runRequest();
                    return callback(result, () => this.subscribe(callback));
                }
                catch (e) {
                    const result = { error: 'network Error' };
                    return callback(result, () => this.subscribe(callback));
                }
            }
        };
    }
}
export default HttpTransport;
